==> structgenie-0.1.2.tar.gz: structgenie-0.1.2/structgenie/errors.py <==
class PromptError(Exception):
    def __init__(self, msg: str):
        self.msg = msg

    def __str__(self):
        return f"{self.msg}"


class TemplateError(Exception):
    def __init__(self, msg: str):
        self.msg = msg

    def __str__(self):
        return f"{self.msg}"


class EngineRunError(Exception):
    def __init__(self, msg: str, context_error: Exception = None):
        self.msg = msg
        self.context = context_error.__class__.__name__ if context_error else None

    def __str__(self):
        if self.context:
            return f"{self.__class__.__name__}({self.msg} | Reason: {self.context})"
        return f"{self.__class__.__name__}({self.msg})"


class MaxRetriesError(EngineRunError):
    pass


# === VALIDATION ERRORS ===

class ValidationError(Exception):
    def __init__(self, msg: str, parent_key: str = None):
        self.msg = msg
        self.parent_key = parent_key

    def __str__(self):
        if self.parent_key:
            return f"{self.__class__.__name__}( {self.msg} > for key '{self.parent_key}')"
        return f"{self.__class__.__name__}( {self.msg} )"


class ValidatorExecutionError(ValidationError):
    pass


class ValidationRuleError(ValidationError):
    pass


class ValidationTypeError(ValidationError):
    pass


class ValidationKeyError(ValidationError):
    pass


class ValidationContentError(ValidationError):
    pass


# === PARSING ERRORS ===

class ParsingError(Exception):
    def __init__(self, msg: str, text: str = None):
        self.msg = msg
        self.generated_text = text

    def __str__(self):
        if self.generated_text:
            return f"{self.__class__.__name__}( {self.msg} > From parsing {self.generated_text} )"
        return f"{self.__class__.__name__}( {self.msg} )"


class ParsingPartialError(ParsingError):
    pass


class ParsingFixingError(ParsingError):
    pass


class MultilineParsingError(ParsingError):
    pass


class YamlParsingError(ParsingError):
    pass


def is_output_error(error: Exception):
    """Check if output is an error."""
    return isinstance(error, ParsingError) or isinstance(error, ValidationError)

==> structgenie-0.1.13.tar.gz: structgenie-0.1.13/structgenie/errors.py <==
class PromptError(Exception):
    def __init__(self, msg: str):
        self.msg = msg

    def __str__(self):
        return f"{self.msg}"


class TemplateError(Exception):
    def __init__(self, msg: str):
        self.msg = msg

    def __str__(self):
        return f"{self.msg}"


# === VALIDATION ERRORS ===

class ValidationError(Exception):
    def __init__(self, msg: str, parent_key: str = None):
        self.msg = msg
        self.parent_key = parent_key

    def __str__(self):
        if self.parent_key:
            return f"{self.__class__.__name__}: {self.msg}\nFor nested output key '{self.parent_key}'\n"
        return f"Error: {self.msg}\n"


class ValidatorExecutionError(ValidationError):
    pass


class ValidationRuleError(ValidationError):
    pass


class ValidationTypeError(ValidationError):
    pass


class ValidationKeyError(ValidationError):
    pass


class ValidationContentError(ValidationError):
    pass


# === PARSING ERRORS ===

class ParsingError(Exception):
    def __init__(self, msg: str, text: str):
        self.msg = msg
        self.generated_text = text

    def __str__(self):
        return f"{self.msg}\n\nGenerated Text:\n{self.generated_text}"


class ParsingPartialError(Exception):
    def __init__(self, msg: str):
        self.msg = msg

    def __str__(self):
        return f"{self.msg}"


class ParsingFixingError(Exception):
    def __init__(self, msg: str):
        self.msg = msg

    def __str__(self):
        return f"{self.msg}"


class MultilineParsingError(Exception):
    pass


class YamlParsingError(Exception):
    pass
